/* Energy Components, http://www.energy-components.com
 * Tietoenator AS,    http://www.tietoenator.com
 *
 * Copyright (c) 2004 Tietoenator AS.  All rights reserved.
 * --------------------------------------------------------
 * $Header: /product/com.ec.frmw.jboss.service/src/com/ec/frmw/jboss/service/ECSchedulerServiceMBean.java,v 1.1 2009/05/13 13:52:57 grimschr Exp $
 */
package com.ec.frmw.jboss.service;

import java.util.Collection;
import java.util.Collections;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.Properties;

import javax.management.AttributeNotFoundException;
import javax.management.InstanceNotFoundException;
import javax.management.MBeanException;
import javax.management.MalformedObjectNameException;
import javax.management.ReflectionException;
import org.quartz.SchedulerException;
import org.w3c.dom.Element;


public interface ECSchedulerServiceMBean  {

    // *** Constants ***
    Map fileNotificationSubscriptions = Collections.synchronizedMap(new HashMap()); 
    Map ecQuartzProperties = Collections.synchronizedMap(new HashMap());
    Map ecActionList = Collections.synchronizedMap(new HashMap());

    final String DB_SANITY_CHECK_SQL = "select count(*) from schedule";
    final String GLOBAL_SERVER_NAME = "GLOBAL";
    final String XML_QUARTZ_SERVER_CONFIG = "quartz-server-config";
    final String XML_SERVER_GLOBAL = "server-global";
    final String XML_SERVER_INSTANCE = "server-instance";
    final String XML_SUBSCRIPTION_ACTIONS = "subscription-actions";
    final String XML_ACTION = "action";
    final String XML_FILTER = "filter";
    final String XML_FILE_NSL = "file-subscription-list";
    final String XML_FILE = "file";
    
    final String STOP_ALL = "STOP_ALL";
    final String RESTART_ALL = "RESTART_ALL";
    final String STOP_ORPHAN = "STOP_ORPHAN";
    final String START_MISSING = "START_MISSING";
    final String STOP_ORPHAN_AND_START_MISSING = "STOP_ORPHAN_AND_START_MISSING";

    final String PROP_KEY_IGNORE_SANITY_CHECK = "com.ec.frmw.scheduler.StartWithoutSanityCheck";
    final String PROP_KEY_STARTUP_STATE = "com.ec.frmw.scheduler.StartupState";
    final String PROP_KEY_INITIAL_STARTUP_STATE = "InitialStartupState";
    
    final String SERVER_STATE_RUNNING = "SERVER_STATE_RUNNING";
    final String SERVER_STATE_STANDBY = "SERVER_STATE_STANDBY";
    final String SERVER_STATE_SHUTDOWN = "SERVER_STATE_SHUTDOWN";
    /*
    <quartz-server-config>
        <server-global>
            some-global-properties here
        </server-global>
    
        <server-instance name="QWERTY">
            some-QWERTY-properties here
        </server-instance>
        
        <server-instance name="ABCDE">
            some-ABCDE-properties here
        </server-instance>
        
    </quartz-server-config>
    */
    

    
    // *** Methods ***
    void setQuartzProperties(Element quartzProperties) throws Exception;
    void setSubscriptionAction(Element subscriptionActions) throws Exception;
    void setFileSubscriptionList(Element fileSubscriptions) throws Exception;
    
    Properties getQuartzProperties(String serverName);
    
    String getClusterPartitionName();
    boolean isNodeMemberOfCluster();
    
    String getECSchedulePinTo();
    
    List getLocalRunningJobs(String name) throws SchedulerException, MalformedObjectNameException, AttributeNotFoundException, InstanceNotFoundException, MBeanException, ReflectionException;
    List getRunningJobs(String name) throws Exception;
    
    boolean interruptLocalJobs(String sysname, String groupName, String jobName, String jobInstanceIdHashCode);
    List interruptJobs(String sysname, String groupName, String jobName) throws Exception;
    List interruptJob(String sysname, String jobInstanceIdHashCode) throws Exception;

    String setLocalStateRunning(String name);
    String setLocalStateRunning(String node, String name);
    List setStateRunningOnAllNodes(String sysname) throws Exception;
    String setStateRunning(String fullname) throws Exception;
    
    String setLocalStateStandBy(String sysname);
    String setLocalStateStandBy(String node, String sysname); 
    List setStateStandByOnAllNodes(String sysname) throws Exception;
    String setStateStandBy(String fullname) throws Exception;
    
    String getLocalState(String sysname);
    String getLocalState(String node, String sysname);
    List getStateFromAllNodes(String sysname) throws Exception;
    String getState(String fullName) throws Exception;
    
    Map getLocalInfo(String sysname)  throws Exception;
    List getInfoFromAllNodes(String sysname)  throws Exception ;
    String getLocalNodeName();
    List getNodeNames() throws Exception;

    Collection getLocalSystemNames();
    Collection getSystemNames() throws Exception;

    void dumpToPath(String path) throws Exception;
    void dumpToPath(String path, String name, String group) throws Exception;
    void loadFromPath(String path) throws Exception;
    
}
